Learn R Programming

WaterBalanceR (version 0.1.19)

DownloadET0fromArable: Downloads reference evapotranspiration (ET0) from an Arable account and processes the data for a given period. Only devices located within (or inside a 500 m buffer around) the provided shapefile are considered.

Description

Downloads reference evapotranspiration (ET0) from an Arable account and processes the data for a given period. Only devices located within (or inside a 500 m buffer around) the provided shapefile are considered.

Usage

DownloadET0fromArable(
  user_name = NA,
  pwd = NA,
  start_date = NA,
  end_date = NA,
  shape_site = NA
)

Value

chart containing reference evapotranspiration for every DOY during given timespan

Arguments

user_name

string: "user_name"

pwd

DOY string: "password"

start_date

Start date of download (string: "YYYY-MM-DD")

end_date

End date of download (string: "YYYY-MM-DD")

shape_site

Path to shapefile containing your AOI (string).