Learn R Programming

WaterBalanceR (version 0.1.19)

DownloadET0fromDWD: Downloads daily reference evapotranspiration (ET0) grids from the German Weather Service (DWD) open data portal for a given year, extracts the values for a specified AOI (shapefile), and saves the results as a .csv file with daily ET0 values.

Description

Downloads daily reference evapotranspiration (ET0) grids from the German Weather Service (DWD) open data portal for a given year, extracts the values for a specified AOI (shapefile), and saves the results as a .csv file with daily ET0 values.

Usage

DownloadET0fromDWD(
  target_path = NA,
  test_site_shp = NA,
  target_year = NA,
  timeout = 1000
)

Value

chart containing reference evapotranspiration for every DOY during given timespan

Arguments

target_path

Path to download and save csv-file with reference ET for your AOI and timespan of interest

test_site_shp

Path to shapefile containing your AOI (string).

target_year

year of interest (integer: 2021)

timeout

time out span for downloading data (default: 10000, exceed, if your interconnection is slow)