Learn R Programming

WaterBalanceR (version 0.1.19)

calcWBplots: Create .png files for results at a first glance

Description

Create .png files from .RDATA file created by calcWB() for every DOY within given timespan (earliest till latest NDVI-capture) showing NDVI, crop coefficient, crop evapotranspiration, precipitation, irrigation and water balance. Besides, .RDATA file is created, that contains mean values for selected samples.

Usage

calcWBplots(source_path = NA, plant_doy = NA, buffer20 = NA, shape_site = NA)

Value

.png files for every DOY within given timespan (earliest till latest NDVI-capture) showing NDVI, crop coefficient, crop evapotranspiration, precipitation, irrigation and water balance

Arguments

source_path

Path to .RDATA file (string) resulting from calcWB() function.

plant_doy

DOY (integer), when planted.

buffer20

Path to buffer (string) containing shapefile with buffers of interest within study site. Read with sf::read_st().

shape_site

Path to shapefile containing your AOI (string).