Processes downloaded csv-files from using DownloadRaindancer() to a shapefile. The resulting shapefile is being updated every time, this script is being run.
DownloadRaindancerCombineCharts(
sourcepath = NA,
targetpath = NA,
start_date = paste(substr(Sys.Date(), 1, 4), "-01-01", sep = ""),
nozzle_diameter = "25_4",
target_crs = 32633
)A shapefile, that contains all irrigation events, that were download. The shapefile is being opdated every time this script is being run, as long as all configuration parameter stay the same.
Path (string) to Firefox download folder. Look it up in your Firefox browser.
Path (string) to destination folder for downloaded csv-files from Raindancer.
You need to define a start date (default: 1st Jan of recent year)
diameter of nozzle in mm (string, e.g. 17_8 = 17.8 mm). Default is "25_4".
target crs