Create .png files from .RDATA file created by calcWB() for every DOY within given timespan (earliest till latest NDVI-capture) showing NDVI, crop coefficient, crop evapotranspiration, precipitation, irrigation and water balance. Besides, .RDATA file is created, that contains mean values for selected samples.
calcWBplots(source_path = NA, plant_doy = NA, buffer20 = NA, shape_site = NA).png files for every DOY within given timespan (earliest till latest NDVI-capture) showing NDVI, crop coefficient, crop evapotranspiration, precipitation, irrigation and water balance
Path to .RDATA file (string) resulting from calcWB() function.
DOY (integer), when planted.
Path to buffer (string) containing shapefile with buffers of interest within study site. Read with sf::read_st().
Path to shapefile containing your AOI (string).